==> zio-aws-amplifyuibuilder_3-5.19.8.1-sources.jar: zio/aws/amplifyuibuilder/model/ComponentEvent.scala <==
package zio.aws.amplifyuibuilder.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ComponentEvent(
    action: Optional[String] = Optional.Absent,
    bindingEvent: Optional[String] = Optional.Absent,
    parameters: Optional[zio.aws.amplifyuibuilder.model.ActionParameters] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.ComponentEvent = {
    import ComponentEvent.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.ComponentEvent
      .builder()
      .optionallyWith(action.map(value => value: java.lang.String))(_.action)
      .optionallyWith(bindingEvent.map(value => value: java.lang.String))(
        _.bindingEvent
      )
      .optionallyWith(parameters.map(value => value.buildAwsValue()))(
        _.parameters
      )
      .build()
  }
  def asReadOnly: zio.aws.amplifyuibuilder.model.ComponentEvent.ReadOnly =
    zio.aws.amplifyuibuilder.model.ComponentEvent.wrap(buildAwsValue())
}
object ComponentEvent {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.ComponentEvent
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.ComponentEvent =
      zio.aws.amplifyuibuilder.model.ComponentEvent(
        action.map(value => value),
        bindingEvent.map(value => value),
        parameters.map(value => value.asEditable)
      )
    def action: Optional[String]
    def bindingEvent: Optional[String]
    def parameters
        : Optional[zio.aws.amplifyuibuilder.model.ActionParameters.ReadOnly]
    def getAction: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("action", action)
    def getBindingEvent: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("bindingEvent", bindingEvent)
    def getParameters: ZIO[
      Any,
      AwsError,
      zio.aws.amplifyuibuilder.model.ActionParameters.ReadOnly
    ] = AwsError.unwrapOptionField("parameters", parameters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ComponentEvent
  ) extends zio.aws.amplifyuibuilder.model.ComponentEvent.ReadOnly {
    override val action: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.action())
      .map(value => value: String)
    override val bindingEvent: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.bindingEvent())
      .map(value => value: String)
    override val parameters
        : Optional[zio.aws.amplifyuibuilder.model.ActionParameters.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parameters())
        .map(value =>
          zio.aws.amplifyuibuilder.model.ActionParameters.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ComponentEvent
  ): zio.aws.amplifyuibuilder.model.ComponentEvent.ReadOnly = new Wrapper(impl)
}

==> zio-aws-amplifyuibuilder_3-6.20.162.1-sources.jar: zio/aws/amplifyuibuilder/model/ComponentEvent.scala <==
package zio.aws.amplifyuibuilder.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ComponentEvent(
    action: Optional[String] = Optional.Absent,
    parameters: Optional[zio.aws.amplifyuibuilder.model.ActionParameters] =
      Optional.Absent,
    bindingEvent: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.ComponentEvent = {
    import ComponentEvent.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.ComponentEvent
      .builder()
      .optionallyWith(action.map(value => value: java.lang.String))(_.action)
      .optionallyWith(parameters.map(value => value.buildAwsValue()))(
        _.parameters
      )
      .optionallyWith(bindingEvent.map(value => value: java.lang.String))(
        _.bindingEvent
      )
      .build()
  }
  def asReadOnly: zio.aws.amplifyuibuilder.model.ComponentEvent.ReadOnly =
    zio.aws.amplifyuibuilder.model.ComponentEvent.wrap(buildAwsValue())
}
object ComponentEvent {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.ComponentEvent
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.ComponentEvent =
      zio.aws.amplifyuibuilder.model.ComponentEvent(
        action.map(value => value),
        parameters.map(value => value.asEditable),
        bindingEvent.map(value => value)
      )
    def action: Optional[String]
    def parameters
        : Optional[zio.aws.amplifyuibuilder.model.ActionParameters.ReadOnly]
    def bindingEvent: Optional[String]
    def getAction: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("action", action)
    def getParameters: ZIO[
      Any,
      AwsError,
      zio.aws.amplifyuibuilder.model.ActionParameters.ReadOnly
    ] = AwsError.unwrapOptionField("parameters", parameters)
    def getBindingEvent: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("bindingEvent", bindingEvent)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ComponentEvent
  ) extends zio.aws.amplifyuibuilder.model.ComponentEvent.ReadOnly {
    override val action: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.action())
      .map(value => value: String)
    override val parameters
        : Optional[zio.aws.amplifyuibuilder.model.ActionParameters.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parameters())
        .map(value =>
          zio.aws.amplifyuibuilder.model.ActionParameters.wrap(value)
        )
    override val bindingEvent: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.bindingEvent())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ComponentEvent
  ): zio.aws.amplifyuibuilder.model.ComponentEvent.ReadOnly = new Wrapper(impl)
}
